' *****************************************************************
'  Mini application ralise par Ronald Vasseur
'  rdacteur pour le site Developpez.com  
' 
'  Autres ressources disponibles sur http://webman.developpez.com
'  Mon blog : http://blog.developpez.com/?blog=52
'
' *****************************************************************
Option Explicit On
Option Strict On

Imports System.IO
Imports System.Text
Imports System.Net
Imports System.Net.NetworkInformation
Imports System.Globalization

Public Class NetworkInfos

    Private mesInterfaces() As NetworkInterface
    Private monInterface As NetworkInterface
    Private monNumberFormat As NumberFormatInfo


    Private Sub NetworkInfos_Load(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles MyBase.Load

        System.Windows.Forms.Application.EnableVisualStyles()



        cbInterfaces.Items.Clear()

        Try
            ' Rcupartion de la liste des interfaces rseau
            mesInterfaces = NetworkInterface.GetAllNetworkInterfaces
            Dim inter As NetworkInterface = Nothing
            For Each inter In mesInterfaces
                cbInterfaces.Items.Add(inter.Description)
            Next

            cbInterfaces.SelectedIndex = 0

        Catch ex As Exception

            cbInterfaces.Items.Add("Impossible de dtecter une interface sur cette machine")

        End Try
    End Sub


#Region "Interfaces rseaux"

    Private Sub cbInterfaces_SelectedIndexChanged(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles cbInterfaces.SelectedIndexChanged
        ' Modification de l'interface  examiner en fonction du choix de l'utilisateur
        monInterface = mesInterfaces(cbInterfaces.SelectedIndex)
    End Sub

    ' Affichage des informations relatives aux interfaces rseau
    Private Sub getStatsConnexion()

        ' Affichage de la vitesse de la connexion
        lblVitesse.Text = formateVitesseConnexion(monInterface.Speed)
        ' Affichage du statut de la connexion
        lblStatut.Text = getStatutConnexion()
        ' Affichage du nombre d'octets envoys sur cette connexion
        lblEnvoyes.Text = getOctetsEnvoyes()
        ' Affichage du nombre d'octets reus sur cette connexion
        lblRecus.Text = getOctetsRecus()
        ' Affichage des informations du protocole IP de la connexion
        getInfosIp()


    End Sub

    ' Formatte la vitesse pour qu'elle soit plus 'lisible'
    Private Function formateVitesseConnexion(ByVal vitesseBrute As Long) As String

        Dim vitesse As String = Nothing

        ' Formatage de la vitesse de la connexion
        Try

            Select Case vitesseBrute
                Case 10000000
                    vitesse = "10 Mbits/s"
                Case 11000000
                    vitesse = "11 Mbits/s"
                Case 54000000
                    vitesse = "54 Mbits/s"
                Case 100000000
                    vitesse = "100 Mbits/s"
                Case 108000000
                    vitesse = "108 Mbits/s"
                Case 1000000000
                    vitesse = "1 Gbits/s"
                Case Else
                    vitesse = (vitesseBrute / 1000000).ToString & " Mbits/s"
            End Select

        Catch ex As Exception
            vitesse = "Non dispo."
        End Try

        Return vitesse

    End Function
    ' Obtient le statut de la connexion rseau
    Private Function getStatutConnexion() As String

        Return monInterface.OperationalStatus.ToString

    End Function

    ' Obtient le nombre de Ko envoys
    Private Function getOctetsEnvoyes() As String

        Dim octetsEnvoyes As Double = Nothing
        Dim octetsEnvoyesFormate As String = Nothing

        Try

            Dim mesStats As IPv4InterfaceStatistics = monInterface.GetIPv4Statistics
            ' Rcupration et conversion du nombre d'octets envoys en Mo
            octetsEnvoyes = Math.Round(mesStats.BytesSent / 1024)
            octetsEnvoyesFormate = octetsEnvoyes & " Ko"

        Catch ex As Exception

            octetsEnvoyesFormate = "Non dispo."

        End Try

        Return octetsEnvoyesFormate

    End Function

    ' Obtient le nombre de Ko reus
    Private Function getOctetsRecus() As String

        Dim octetsRecus As Double = Nothing
        Dim octetsRecusFormate As String = Nothing

        Try

            Dim mesStats As IPv4InterfaceStatistics = monInterface.GetIPv4Statistics
            ' Rcupration et conversion du nombre d'octets reus en Mo
            octetsRecus = Math.Round(mesStats.BytesReceived / 1024)
            octetsRecusFormate = octetsRecus & " Ko"

        Catch ex As Exception

            octetsRecusFormate = "Non dispo."

        End Try

        Return octetsRecusFormate

    End Function

    ' Obtient les informations relatives au protocole IP
    Private Sub getInfosIp()

        ' Nettoyage de la ListBox qui va contenir les informations
        lbInfosIp.Items.Clear()

        Try

            ' Rcupration de la totalit des proprits IP de l'interface slectionne
            Dim mesProprietesReseau As IPInterfaceProperties = monInterface.GetIPProperties()


            ' Rcupre les adresses unicast lies  cette interface
            Dim infosUnicast As UnicastIPAddressInformationCollection = mesProprietesReseau.UnicastAddresses
            Dim adresseIp As IPAddressInformation
            ' Affichage de l'adresse IP de l'interface
            For Each adresseIp In infosUnicast
                lbInfosIp.Items.Add("Adresse IP : " & adresseIp.Address.ToString())
            Next

            ' Rcupre les informations relatives  DNS
            Dim infosDns As IPAddressCollection = mesProprietesReseau.DnsAddresses
            Dim adresseDns As IPAddress
            ' Affichage dans la ListBox des adresses DNS de l'interface
            For Each adresseDns In infosDns
                lbInfosIp.Items.Add("Adresse DNS : " & adresseDns.ToString)
            Next

            ' Si protocole DHCP activ sur l'interface alors recherche de l'adresse du serveur DHCP
            If mesProprietesReseau.GetIPv4Properties.IsDhcpEnabled = True Then

                Dim infosDhcp As IPAddressCollection = mesProprietesReseau.DhcpServerAddresses
                Dim adresseDhcp As IPAddress
                ' Affichage dans la ListBox de l'adresse du serveur DHCP
                For Each adresseDhcp In infosDhcp
                    lbInfosIp.Items.Add("Adresse DHCP : " & adresseDhcp.ToString)
                Next
            End If

            ' Rcupration des proprits relatives  la passerelle
            Dim infosPasserelle As GatewayIPAddressInformationCollection = mesProprietesReseau.GatewayAddresses
            Dim ipPasserelle As GatewayIPAddressInformation
            ' Affichage dans la ListBox de l'adresse de la passerelle IP
            For Each ipPasserelle In infosPasserelle
                lbInfosIp.Items.Add("Passerelle IP : " & ipPasserelle.Address.ToString())
            Next

            ' Rcupartion des adresses de multicast de l'interface slectionne
            Dim infosMulticast As MulticastIPAddressInformationCollection = mesProprietesReseau.MulticastAddresses
            Dim multicastAdresse As MulticastIPAddressInformation

            ' Affichage dans la ListBox des adresses de multicast
            For Each multicastAdresse In infosMulticast
                lbInfosIp.Items.Add("IP multicast : " & multicastAdresse.Address.ToString())
            Next


        Catch ex As Exception
            MessageBox.Show("Une erreur est survenue : " & ex.Message)
        End Try

    End Sub


    Private Sub btActualiser_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btActualiser.Click
        ' Appel de toutes les informations relatives  l'interface
        getStatsConnexion()
    End Sub


    Private Sub btTransfert_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btTransfert.Click

        Dim strSource As String = Nothing
        Dim strDestination As String = Nothing
        Dim strIdentifiant As String = Nothing
        Dim strMotDePasse As String = Nothing

        ' Vrification de la prsence d'un chemin pour la source
        If tbSource.Text.Length < 1 Then
            MessageBox.Show("Veuillez fournir un chemin pour la source !")
            Exit Sub
        Else
            strSource = tbSource.Text
        End If


        ' Vrification de la prsence d'un chemin pour la destination
        If tbDestination.Text.Length < 1 Then
            MessageBox.Show("Veuillez fournir un chemin pour la destination !")
            Exit Sub
        Else
            strDestination = tbDestination.Text
        End If

        ' Rcupration de l'identifiant et du mot de passe
        strIdentifiant = tbLogin.Text
        strMotDePasse = tbPassword.Text


        ' Dtection de la fonctionnalit demande : download ou upload
        If rbUpload.Checked = True Then

            Try

                ' Upload d'un fichier vers un serveur FTP
                uploadFichier(strSource, strDestination, strIdentifiant, strMotDePasse)

            Catch ex As Exception

                MessageBox.Show("Une erreur est survenue : " & ex.Message)
                Exit Sub

            End Try

        Else

            Try

                ' Download d'un fichier depuis un serveur FTP
                downloadFichier(strSource, strDestination, strIdentifiant, strMotDePasse)

            Catch ex As Exception

                MessageBox.Show("Une erreur est survenue : " & ex.Message)
                Exit Sub

            End Try

        End If

    End Sub

#End Region


#Region "Ping"

    Private Sub btPing_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btPing.Click


        ' Vrifie que l'utilisateur  saisi quelque chose dans la zone TextBox
        If tbPing.Text.Length <> 0 Then

            ' Essaye d'envoyer un ping vers l'adresse fournit
            lbResultat.Items.Add(getPingTime(tbPing.Text))

        Else

            MessageBox.Show("Veuillez entrer une adresse IP ou un nom d'hte.")

        End If



    End Sub

    ' Obtient le dlai du Ping en millisecondes
    Private Function getPingTime(ByVal adresseIP As String) As String
        ' AdresseIP : chane de caractre contenant l'adresse IP de l'hte  "pinger"

        ' Instanciation d'un objet Ping
        Dim monPing As New Ping

        ' Objet PingReply qui nous permettra de rcuprer le rsultat
        Dim maReponsePing As PingReply
        Dim resultatPing As String = Nothing

        Try

            ' Rcupration du rsultat obtenu par la mthode Send()
            maReponsePing = monPing.Send(adresseIP, Nothing)
            ' Formatage du rsultat avec rcupration du temps en millisecondes
            ' grce  la proprit RoundtripTime.
            resultatPing = "Rponse de " & adresseIP & " en " & maReponsePing.RoundtripTime.ToString & " ms."

            Return resultatPing

        Catch ex As PingException

            ' Formatage de l'exception affiche
            resultatPing = "Impossible de joindre l'hte : " & ex.Message
            Return resultatPing

        End Try

    End Function

#End Region


#Region "FTP"

    ' Download d'un fichier depuis un serveur FTP
    Private Sub downloadFichier(ByVal strUrlFichier As String, ByVal strCheminDestinationFichier As String, ByVal identifiant As String, ByVal motDePasse As String)

        ' strUrlFichier : Uri du fichier sur le serveur FTP
        ' strCheminDestinationFichier : Uri du fichier sur le disque dur
        ' identifiant : login du compte FTP utilis
        ' motDePasse : mot de passe du compte FTP utilis



        ' Instanciation de deux Uri qui vont contenir les chemins source et destination
        Dim monUriFichier As New System.Uri(strUrlFichier)
        Dim monUriDestinationFichier As New System.Uri(strCheminDestinationFichier)

        ' Vrification de la validit de l'Uri du fichier sur le serveur FTP
        If Not (monUriFichier.Scheme = Uri.UriSchemeFtp) Then
            MessageBox.Show("L'Uri du fichier sur le serveur FTP n'est pas valide", "Une erreur est surevnue", MessageBoxButtons.OK, MessageBoxIcon.Warning)
            ' Si Uri non valide arrt du tlchargement
            Exit Sub
        End If

        ' Vrification de la validit de l'Uri de l'emplacement du fichier de destination
        If Not (monUriDestinationFichier.Scheme = Uri.UriSchemeFile) Then
            MessageBox.Show("Le chemin de destination n'est pas valide !", "Une erreur est surevnue", MessageBoxButtons.OK, MessageBoxIcon.Warning)
            ' Si Uri non valide arrt du tlchargement
            Exit Sub
        End If

        ' Cration des 2 flux et du reader ncessaire pour la rcupration du fichier
        Dim monResponseStream As Stream = Nothing
        Dim monFileStream As FileStream = Nothing
        Dim monReader As StreamReader = Nothing

        Try

            ' Requte demandant le fichier se trouvant sur le serveur FTP
            Dim downloadRequest As FtpWebRequest = CType(WebRequest.Create(monUriFichier), FtpWebRequest)

            ' Vrification de la prsence des identifiant d'un compte, si aucun alors
            ' la connexion se fait en mode anonyme
            If Not identifiant.Length = 0 Then
                Dim monCompteFtp As New NetworkCredential(identifiant, motDePasse)
                downloadRequest.Credentials = monCompteFtp
            End If

            ' Flux de donnes issu du fichier sur le serveur FTP
            Dim downloadResponse As FtpWebResponse = CType(downloadRequest.GetResponse(), FtpWebResponse)
            monResponseStream = downloadResponse.GetResponseStream()

            ' Chemin de desination du fichier sur le disque dur
            Dim nomFichier As String = monUriDestinationFichier.LocalPath.ToString

            ' Cration du fichier de destination sur le disque dur
            monFileStream = File.Create(nomFichier)

            ' Tableau d'octets qui va contenir les donnes issues du flux
            Dim monBuffer(1024) As Byte
            Dim octetsLus As Integer

            ' Lecture du buffer, puis ecriture des donnes dans le fichier
            While True

                ' Lecture du flux
                octetsLus = monResponseStream.Read(monBuffer, 0, monBuffer.Length)
                If octetsLus = 0 Then
                    Exit While
                End If
                ' Ecriture dans le fichier
                monFileStream.Write(monBuffer, 0, octetsLus)

            End While

            MessageBox.Show("Tlchargement effectu.")

            ' Gestion des exceptions
        Catch ex As UriFormatException

            MessageBox.Show(ex.Message)

        Catch ex As WebException
            MessageBox.Show(ex.Message)

        Catch ex As IOException
            MessageBox.Show(ex.Message)

        Finally
            ' Fermeture du reader et des deux streams si ncessaire

            If monReader IsNot Nothing Then
                monReader.Close()
            ElseIf monResponseStream IsNot Nothing Then
                monResponseStream.Close()
            End If

            ' Fermeture du flux et du fichier
            If monFileStream IsNot Nothing Then
                monFileStream.Close()
            End If

        End Try

    End Sub

    ' Upload un fichier sur un serveur FTP
    Private Sub uploadFichier(ByVal cheminSource As String, ByVal urlDestination As String, ByVal identifiant As String, ByVal motDePasse As String)

        ' cheminSource : Uri du fichier sur le disque dur
        ' urlDestination : Uri du fichier de destination sur le serveur FTP
        ' identifiant : login du compte FTP utilis
        ' motDePasse : mot de passe du compte FTP utilis

        Dim monUriFichierLocal As System.Uri = Nothing
        Dim monUriFichierDistant As System.Uri = Nothing

        ' Vrification de la validit de l'Uri de l'emplacement du fichier source
        If Not (monUriFichierLocal.Scheme = Uri.UriSchemeFile) Then
            MessageBox.Show("Le chemin du fichier local n'est pas valide !", "Une erreur est surevnue", MessageBoxButtons.OK, MessageBoxIcon.Warning)
            Exit Sub
        End If

        ' Vrification de la validit de l'Uri de l'emplacement du fichier de destination
        If Not (monUriFichierDistant.Scheme = Uri.UriSchemeFtp) Then
            MessageBox.Show("Le chemin du fichier sur le serveur FTP n'est pas valide !", "Une erreur est surevnue", MessageBoxButtons.OK, MessageBoxIcon.Warning)
            Exit Sub
        End If

        ' Cration des 2 flux et du reader ncessaire pour l'envoi du fichier
        Dim monRequestStream As Stream = Nothing
        Dim fileStream As FileStream = Nothing

        Dim uploadResponse As FtpWebResponse = Nothing

        Try

            ' Requte d'upload d'un fichier vers le serveur
            Dim uploadRequest As FtpWebRequest = CType(WebRequest.Create(urlDestination), FtpWebRequest)

            ' Vrification de la prsence des identifiant d'un compte, si aucun alors
            ' la connexion se fait en mode anonyme
            If Not identifiant.Length = 0 Then

                Dim monCompte As New NetworkCredential(identifiant, motDePasse)
                uploadRequest.Credentials = monCompte

            End If

            uploadRequest.Method = WebRequestMethods.Ftp.UploadFile

            ' Dsactivation du proxy http incompatible avec cette requte
            uploadRequest.Proxy = Nothing

            monRequestStream = uploadRequest.GetRequestStream()
            fileStream = File.Open(cheminSource, FileMode.Open)

            ' Tableau d'octets qui va contenir les donnes issues du fichier
            Dim buffer(1024) As Byte
            Dim bytesRead As Integer

            ' Lecture des donnes et envoi de celle ci dans le flux
            While True

                bytesRead = fileStream.Read(buffer, 0, buffer.Length)
                If bytesRead = 0 Then
                    Exit While
                End If
                ' Ecriture des donnes dans le flux d'upload vers le serveur FTP
                monRequestStream.Write(buffer, 0, bytesRead)

            End While

            ' The request stream must be closed before getting the response.
            monRequestStream.Close()

            uploadResponse = CType(uploadRequest.GetResponse(), FtpWebResponse)
            MessageBox.Show("Upload termin.")

            ' Gestion des exceptions
        Catch ex As UriFormatException
            MessageBox.Show(ex.Message)

        Catch ex As WebException
            MessageBox.Show(ex.Message)

        Catch ex As IOException
            MessageBox.Show(ex.Message)


        Finally

            ' Fermeture des diffrents flux utiliss

            If uploadResponse IsNot Nothing Then
                uploadResponse.Close()
            End If

            If fileStream IsNot Nothing Then
                fileStream.Close()
            End If

            If monRequestStream IsNot Nothing Then
                monRequestStream.Close()
            End If

        End Try


    End Sub

    ' Obtient la liste des fichiers d'un rpertoire donn
    Private Sub listeFichiers(ByVal serveurCible As String, ByVal identifiant As String, ByVal motDePasse As String)

        Dim monResponseStream As Stream = Nothing
        Dim monStreamReader As StreamReader = Nothing


        ' Instanciation de deux Uri qui vont contenir les chemins source et destination
        Dim monUriServeur As New System.Uri(serveurCible)


        ' Vrification de la validit de l'Uri du fichier sur le serveur FTP
        If Not (monUriServeur.Scheme = Uri.UriSchemeFtp) Then
            MessageBox.Show("L'Uri du serveur FTP n'est pas valide", "Une erreur est surevnue", MessageBoxButtons.OK, MessageBoxIcon.Warning)
            'Si Uri non valide arrt du listage
            Exit Sub
        End If

        Try


            ' Cration de la requte de rcupration de la liste des fichiers
            Dim maRequeteListe As FtpWebRequest = CType(WebRequest.Create(monUriServeur), FtpWebRequest)
            maRequeteListe.Method = WebRequestMethods.Ftp.ListDirectoryDetails


            ' Vrification de la prsence des identifiant d'un compte, si aucun alors
            ' la connexion se fait en mode anonyme
            If Not identifiant.Length = 0 Then
                Dim monCompteFtp As New NetworkCredential(identifiant, motDePasse)
                maRequeteListe.Credentials = monCompteFtp
            End If

            ' Rcupration de la liste de fichiers
            Dim maResponseListe As FtpWebResponse = CType(maRequeteListe.GetResponse, FtpWebResponse)
            ' Placement du flux provenant du serveur dans un streamreader
            monStreamReader = New StreamReader(maResponseListe.GetResponseStream, Encoding.Default)

            ' Lecture du stream reader
            Dim listeBrute As String = monStreamReader.ReadToEnd

            ' Dcoupage de chaque fichier dans la liste concatne de fichiers
            Dim separateur() As String = {Environment.NewLine} ' Correspond  un retour chariot
            ' Dcoupage et rcupration des noms de fichiers
            Dim tableauListe() As String = listeBrute.Split(separateur, StringSplitOptions.RemoveEmptyEntries)
            Dim result As New List(Of String)

            ' Lecture du tableau et tri des noms de fichiers
            Dim i As Integer = 0
            While i < tableauListe.Length
                If Not tableauListe(i).StartsWith("d") Then
                    ' On place les noms de fichiers dans une liste
                    result.Add(tableauListe(i).Substring(tableauListe(i).LastIndexOf(" ") + 1))
                End If
                i += 1
            End While

            Dim nomFichier As String

            ' On place la liste de fichier dans la Combo-box
            For Each nomFichier In result
                cbFichiers.Items.Add(nomFichier)
            Next
            cbFichiers.SelectedItem = cbFichiers.Items.Item(0)

            MessageBox.Show("Liste termine")


            ' Gestion des exceptions
        Catch ex As UriFormatException
            MessageBox.Show(ex.Message)

        Catch ex As WebException
            MessageBox.Show(ex.Message)

        Finally

            ' Fermeture des diffrents flux utiliss
            If monResponseStream IsNot Nothing Then
                monResponseStream.Close()
            End If

            If monStreamReader IsNot Nothing Then
                monStreamReader.Close()
            End If

        End Try

    End Sub

    ' Efface un fichier donn sur un serveur FTP
    Private Sub effaceFichier(ByVal uriFichier As String, ByVal identifiant As String, ByVal motDePasse As String)

        ' Cration d'un URI  partir de la chaine contenant l'URL du serveur FTP
        Dim monUriFichier As New Uri(uriFichier)

        ' Vrification de la validit de l'adresse FTP
        If Not (monUriFichier.Scheme = Uri.UriSchemeFtp) Then
            MessageBox.Show("L'URI du fichier  effacer n'est pas valide", "Une erreur est surevnue", MessageBoxButtons.OK, MessageBoxIcon.Warning)
            'Si Uri non valide arrt du listage
            Exit Sub
        End If

        Try


            ' Cration de la requte d'effacement du fichier
            Dim maRequeteEffacement As FtpWebRequest = CType(WebRequest.Create(uriFichier), FtpWebRequest)
            maRequeteEffacement.Method = WebRequestMethods.Ftp.DeleteFile

            ' Vrification de la prsence des identifiant d'un compte, si aucun alors
            ' la connexion se fait en mode anonyme
            If Not identifiant.Length = 0 Then
                Dim monCompteFtp As New NetworkCredential(identifiant, motDePasse)
                maRequeteEffacement.Credentials = monCompteFtp
            End If

            ' Effacement du fichier et rcupration du rsultat
            Dim maResponseFtp As FtpWebResponse = CType(maRequeteEffacement.GetResponse, FtpWebResponse)

            MessageBox.Show("Rsultat action : " & maResponseFtp.StatusDescription)


        Catch ex As Exception

            MessageBox.Show("Une erreur est surevnue : " & ex.Message, "Une erreur est surevnue", MessageBoxButtons.OK, MessageBoxIcon.Warning)

        End Try

    End Sub

    Private Sub btLister_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btLister.Click
        cbFichiers.Items.Clear()

        If Not tbAdresseServer.Text.Length < 2 Then
            listeFichiers(tbAdresseServer.Text, tbLogin.Text, tbPassword.Text)
        Else
            MessageBox.Show("Veuillez indiquer une adresse pour le serveur FTP !", "Une erreur est surevnue", MessageBoxButtons.OK, MessageBoxIcon.Warning)
        End If


    End Sub

    Private Sub btEffacer_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btEffacer.Click


        Dim choixUtilisateur As DialogResult = MessageBox.Show("Confirmez-vous la suppression du fichier : " & cbFichiers.SelectedItem.ToString, "Attntion", MessageBoxButtons.YesNo, MessageBoxIcon.Warning)

        ' En fonction du choix de l'utilisateur efface ou non le fichier
        If choixUtilisateur = Windows.Forms.DialogResult.Yes Then

            Dim uriFichier As String = Nothing
            Dim strAdresseServeur As String = Nothing

            strAdresseServeur = tbAdresseServer.Text


            ' Si l'URL ne se termine pas par un "/" on en ajoute un
            If Not strAdresseServeur.EndsWith("/") Then
                strAdresseServeur = strAdresseServeur & "/"
            Else
                strAdresseServeur = strAdresseServeur
            End If

            uriFichier = strAdresseServeur & cbFichiers.SelectedItem.ToString

            effaceFichier(uriFichier, tbLogin.Text, tbPassword.Text)

        Else
            Exit Sub
        End If

    End Sub

    Private Sub btChemin_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btChemin.Click

        Dim openFileDialog1 As New OpenFileDialog()

        openFileDialog1.InitialDirectory = My.Computer.FileSystem.SpecialDirectories.MyDocuments
        openFileDialog1.Filter = "txt files (*.txt)|*.txt|All files (*.*)|*.*"
        openFileDialog1.FilterIndex = 2
        openFileDialog1.RestoreDirectory = True
        ' Empche de slectionner plusieurs fichiers  la fois
        openFileDialog1.Multiselect = False
        ' Titre de la fentre
        openFileDialog1.Title = "Slectionnez un fichier source..."

        ' Rcupration et affichage du fichier slectionn
        If openFileDialog1.ShowDialog() = DialogResult.OK Then
            tbSource.Text = openFileDialog1.FileName.ToString
        End If


    End Sub

    Private Sub btChemin2_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btChemin2.Click
        Dim openFileDialog1 As New OpenFileDialog()

        openFileDialog1.InitialDirectory = My.Computer.FileSystem.SpecialDirectories.MyDocuments
        openFileDialog1.Filter = "txt files (*.txt)|*.txt|All files (*.*)|*.*"
        openFileDialog1.FilterIndex = 2
        openFileDialog1.RestoreDirectory = True
        ' Empche de slectionner plusieurs fichiers  la fois
        openFileDialog1.Multiselect = False
        ' Titre de la fentre
        openFileDialog1.Title = "Slectionnez un fichier source..."

        ' Rcupration et affichage du fichier slectionn
        If openFileDialog1.ShowDialog() = DialogResult.OK Then
            tbDestination.Text = openFileDialog1.FileName.ToString
        End If

    End Sub


#End Region


#Region "Evnements _Click des boutons"

    Private Sub MonsousdomaineToolStripMenuItem_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles MonsousdomaineToolStripMenuItem.Click
        System.Diagnostics.Process.Start("http://webman.developpez.com")
    End Sub

    Private Sub MonblogToolStripMenuItem_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles MonblogToolStripMenuItem.Click
        System.Diagnostics.Process.Start("http://blog.developpez.com/?blog=52")
    End Sub

    Private Sub btQuitter_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btQuitter.Click
        Application.Exit()
    End Sub


#End Region


End Class